Learn R Programming

Rdsdp (version 1.0.6)

Rdsdp: R interface to DSDP semidefinite programming library

Description

Rdsdp is the R package providing a R interface to DSDP semidefinite programming library. The DSDP package implements a dual-scaling algorithm to find solutions (\(X\), \(y\)) to linear and semidefinite optimization problems of the form $$\mbox{(P)} \ \inf\, \mbox{tr}(CX)$$ $$\mbox{subject to}\; \mathcal{A}X = b$$ $$X \succeq 0$$ with \((\mathcal{A}X)_i = \mbox{tr}(A_iX)\) where \(X \succeq 0\) means X is positive semidefinite, \(C\) and all \(A_i\) are symmetric matrices of the same size and \(b\) is a vector of length \(m\).

The dual of the problem is $$\mbox{(D)} \ \sup\, b^{T}y$$ $$\mbox{subject to}\; \mathcal{A}^{*}y + S = C$$ $$S \succeq 0$$

where \(\mathcal{A}y = \sum_{i=1}^m y_i A_i.\)

Matrices \(C\) and \(A_i\) are assumed to be block diagonal structured, and must be specified that way (see Details).

Arguments

References