Rdsdp is the R package providing a R interface to DSDP semidefinite programming library. The DSDP package implements a dual-scaling algorithm to find solutions (\(X\), \(y\)) to linear and semidefinite optimization problems of the form $$\mbox{(P)} \ \inf\, \mbox{tr}(CX)$$ $$\mbox{subject to}\; \mathcal{A}X = b$$ $$X \succeq 0$$ with \((\mathcal{A}X)_i = \mbox{tr}(A_iX)\) where \(X \succeq 0\) means X is positive semidefinite, \(C\) and all \(A_i\) are symmetric matrices of the same size and \(b\) is a vector of length \(m\).
The dual of the problem is $$\mbox{(D)} \ \sup\, b^{T}y$$ $$\mbox{subject to}\; \mathcal{A}^{*}y + S = C$$ $$S \succeq 0$$
where \(\mathcal{A}y = \sum_{i=1}^m y_i A_i.\)
Matrices \(C\) and \(A_i\) are assumed to be block diagonal structured, and must be specified that way (see Details).
Steven J. Benson and Yinyu Ye:
Algorithm 875: DSDP5 software for semidefinite programming ACM Transactions on Mathematical Software (TOMS) 34(3), 2008
http://web.stanford.edu/~yyye/DSDP5-Paper.pdf
Steven J. Benson and Yinyu Ye and Xiong Zhang:
Solving Large-Scale Sparse Semidefinite Programs for Combinatorial Optimization SIAM Journal on Optimization 10(2):443-461, 2000
http://web.stanford.edu/~yyye/yyye/largesdp.ps.gz